Battery
=======

.. autoclass:: physics.models.battery.BasicBattery
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: physics.models.battery.BaseBattery
   :members:
   :undoc-members:
   :show-inheritance: